<?php

    /**
     * For full documentation, please visit: http://docs.reduxframework.com/
     * For a more extensive sample-config file, you may look at:
     * https://github.com/reduxframework/redux-framework/blob/master/sample/sample-config.php
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "businessoneopt";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        'opt_name' => 'businessoneopt',
        'display_name' => 'Business One WordPress Theme &nbsp;&nbsp;&nbsp;&nbsp; <a href="mailto:burak_sdu@outlook.com" target="_blank">Get Professional Help with Business One Theme</a>&nbsp;&nbsp;&nbsp;',
        'page_slug' => 'businessone_options',
        'page_title' => 'businessone Options',
        'update_notice' => FALSE,
        'footer_text' => '<p>You can look at all of my portfolio <a href="https://burak-aydin.com/">here</a></p>',
        'admin_bar' => TRUE,
        'menu_type' => 'menu',
        'menu_title' => 'Business One Options',
        'allow_sub_menu' => TRUE,
        'page_parent_post_type' => 'your_post_type',
        'page_priority' => '62',
        'default_mark' => '*',
        'google_api_key' => 'business-one',
        'hints' => array(
            'icon_position' => 'right',
            'icon_size' => 'normal',
            'tip_style' => array(
                'color' => 'light',
            ),
            'tip_position' => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect' => array(
                'show' => array(
                    'duration' => '500',
                    'event' => 'mouseover',
                ),
                'hide' => array(
                    'duration' => '500',
                    'event' => 'mouseleave unfocus',
                ),
            ),
        ),
        'output' => TRUE,
        'output_tag' => TRUE,
        'settings_api' => TRUE,
        'cdn_check_time' => '1440',
        'compiler' => TRUE,
        'page_permissions' => 'manage_options',
        'save_defaults' => TRUE,
        'show_import_export' => TRUE,
        'transient_time' => '3600',
        'network_sites' => TRUE,
        'display_version' => '1.0',
        'dev_mode' => false
    );

    // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
    $args['share_icons'][] = array(
        'url'   => 'https://burak-aydin.com/',
        'title' => 'Visit our page',
        'icon'  => 'el el-website'
        //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
    );   
 

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_html__( 'Support', 'business-one' ),
            'content' => __( '<p>For your any question or issue, please use our support center : <a href="https://burak-aydin.com/" target="_blank">click</a></p>', 'business-one' )
        ),
       
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = __( '<p><a href="https://burak-aydin.com/" target="_blank">burak-aydin.com</a></p>', 'business-one' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

     /* General */
    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'General', 'business-one' ),
        'id'               => 'styling',               
        'icon'             => 'el el-cogs'
    ) );   


    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Color', 'business-one' ),
        'id'         => 'color-Color',        
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'main-color',
                'type'     => 'color',
                'output'   => array(
                        'background-color'  =>  '.header-info, .front-blog .post-meta-wrap,
                        .woocommerce-tabs input[type="submit"],.header-nav .social-wrap a:hover,.header-nav .nav-menu .get-quote,.section-gallery .scaffholding,.home-blog.single-blog .tags a:hover,.footer-widget .business-details .col-sm-4,.pricing-block.active .info,.businessone-carousel .owl-prev:hover,.businessone-carousel .owl-next:hover,.front-shop .h-product .hover-content a,.single-product .single_add_to_cart_button,.businessone-btn1,.businessone-btn4:hover',

                        'border-color'      =>  '.header-nav .social-wrap a:hover,.home-blog.single-blog .tags a:hover,.businessone-carousel .owl-prev:hover,.businessone-carousel .owl-next:hover,blockquote',

                        'color'             =>  '.header-nav .info,.front-blog em,.header-info .icon-block .fa, .footer-copyright a:hover .fa'

                    ),
                'title'    => esc_html__( 'Main Theme Color', 'business-one' ),
                'subtitle' => esc_html__( 'Pick a color for the theme (default: #ff9d4c).', 'business-one' ),
                'default'  => '#ff9d4c',
            ),

            array(
                'id'       => 'second-color',
                'type'     => 'color',
                'output'   => array(
                        'background-color'  =>  '.businessone-btn1:hover,.businessone-line:after,.get-quote:hover,.section-gallery.front .scaffholding:hover a:hover,.pricing-block .heading,.section-comment .businessone-respond .businessone-btn1,.businessone-headtitle:after,
                        .vc_tta-color-white.vc_tta-style-flat .vc_tta-panel.vc_active .vc_tta-panel-title>a:after,.businessone-testi-carousel .owl-controls .owl-dot.active,.shop-bag .buttons a:hover,.businessone-btn2:hover,.businessone-btn4, .woocommerce-MyAccount-content input[type="submit"]',

                        'border-color'      =>  '.businessone-btn1,.woocommerce-tabs input[type="submit"]:hover,
                        .section-gallery.front .scaffholding:hover a:hover,.businessone-testi-carousel .owl-controls .owl-dot.active,.header-nav .nav-menu > ul > li ul,.shop-bag .buttons a:hover,.woocommerce-message,.businessone-btn2',

                        'color'             =>  '.header-nav .nav-menu a:hover,.front-shop .h-product .p-price,.section-ribbon .align-right,.section-comment .comment-meta-item,.added_to_cart.wc-forward:hover,.price ins,.woocommerce-tabs .nav-tabs li.active a,.section-comment .comment-reply-link:hover,.block-team .second-wrap a:hover,.businessone-testi-carousel em,.businessone-pagenavi span,.shop-content .product-description .price'
                    ),
                'title'    => esc_html__( 'Second Theme Color', 'business-one' ),
                'subtitle' => esc_html__( 'Pick a color for the theme (default: #ff9d4c).', 'business-one' ),
                'default'  => '#ff9d4c',
            ),
        
           
        ),
    ) );


    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Quote Link', 'business-one' ),
        'id'     => 'qoute',                
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'quote-link',
                'type'     => 'text',                
                'title'    => esc_html__( 'Get a Quote Link', 'business-one' ),
                //'desc'     => esc_html__( '', 'business-one' ),                
                'validate' => 'url',
                'default'  => 'http://example.org'
            ),
            
        )
    ) );    



    /* Header */

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Header', 'business-one' ),
        'id'     => 'header-part', 
        'icon'   => 'el el-photo',
        'fields' => array(
            array(
                'id'       => 'logo',
                'type'     => 'media',                
                'title'    => esc_html__( 'Upload Your Logo', 'business-one' ),
                'desc'     => esc_html__( 'Upload your logo image.', 'business-one' ),                
                'default'  => array(
                        'url' => get_template_directory_uri().'/img/logo.png'
                )
            ),
            array(
                'id'       => 'menu-layer',
                'type'     => 'radio',                
                'title'    => esc_html__( 'Top Menu Layer', 'business-one' ),
                //'desc'     => esc_html__( '', 'business-one' ),                
                'options'  => array(
                    '1' => 'Layer 1', 
                    '2' => 'Layer 2',                    
                    '4' => 'Layer 3', 
                ),
                'default' => '1',                
            ), 
            
            // text options
            array(
                'id'       => 'top-text',
                'type'     => 'textarea',                
                'title'    => esc_html__( 'Welcome Message - Left Side', 'business-one' ),
                'default'  => 'Business One WordPress Theme.',
                'required' => array('menu-layer','equals','1')
            ),
            array(
                'id'       => 'top-text-right',
                'type'     => 'textarea',                
                'title'    => esc_html__( 'Welcome Message - Right Side', 'business-one' ),
                'default'  => '<span>+30 3333 33 33</span> | <span>mail@businessone.com</span>',
                'required' => array('menu-layer','equals','1')
            ),            
            array(
                'id'       => 'light-logo',
                'type'     => 'media',                
                'title'    => esc_html__( 'Light Logo', 'business-one' ),
                //'desc'     => esc_html__( '', 'business-one' ),  
                'required' => array('menu-layer','equals','3'),
                'default'  => array(
                        'url' => get_template_directory_uri().'/img/logo-light.png'
                )
            ),
            
                  
        )
    ) );  






    /* Blog */
    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Blog', 'business-one' ),
        'id'               => 'blog-layout',               
        'icon'             => 'el el-website'
    ) ); 


    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Banner', 'business-one' ),
        'id'     => 'styling-banner',                
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'bannerCheck',
                'type'     => 'checkbox',
                'title'    => esc_html__('Enable/Disable', 'business-one'), 
                'subtitle' => esc_html__('You can enable or disable the banner. Default is enabled.', 'business-one'),
                'desc'     => esc_html__('Check or uncheck', 'business-one'),         
                'default'  => '1'
            ),
            array(
                'id'       => 'banner',
                'type'     => 'media',                
                'title'    => esc_html__( 'Upload an image', 'business-one' ),
                'desc'     => esc_html__( 'Blog top banner image', 'business-one' ),
                'default' => array(
                    'url' => get_template_directory_uri().'/img/banner.png'
                )              
            ), 
            array(
                'id'       => 'banner-text',
                'type'     => 'text',                
                'title'    => esc_html__( 'Banner Text', 'business-one' ),
                'desc'     => esc_html__( 'Blog top banner text', 'business-one' ),                             
            ),                   
        )
    ) );

  

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Footer', 'business-one' ),
        'id'     => 'footer-r', 
        'icon'   => 'el el-photo',
        'fields' => array(
            array(
                'id'       => 'footer',
                'type'     => 'textarea',
                'title'    => esc_html__( 'Footer Copyright Text', 'business-one' ),                
                'desc'     => esc_html__( 'Copyright Information', 'business-one' ),
                'default'  => '© 2018. All rights reserved.'
            ), 
            array(
                'id'       => 'address',
                'type'     => 'text',
                'title'    => esc_html__( 'Address', 'business-one' ),                
                //'desc'     => esc_html__( '', 'business-one' ),
                'default'  => 'Wonder Lawn, 17 Downtown St, Victoria, Australia'
            ),
            array(
                'id'       => 'support',
                'type'     => 'text',
                'title'    => esc_html__( 'Support', 'business-one' ),                
                //'desc'     => esc_html__( '', 'business-one' ),
                'default'  => '+90 123 123 23 23'
            ),
            array(
                'id'       => 'get-quote',
                'type'     => 'text',
                'title'    => esc_html__( 'Get a Quote', 'business-one' ),                
                //'desc'     => esc_html__( '', 'business-one' ),
                'default'  => 'mail@example.org'
            ),      
        )
    ) );    


    // -> START Typography
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Typography', 'business-one' ),
        'id'     => 'typography',       
        'icon'   => 'el el-font',
        'fields' => array(
            array(
                'id'       => 'opt-typography-body',
                'type'     => 'typography',
                'title'    => esc_html__( 'Body Font', 'business-one' ),
                'subtitle' => esc_html__( 'Specify the body font properties.', 'business-one' ),
                'output'   => array('body'),
                'google'   => true,    
                'font-weight' => true,
                'font-backup' => true,            
                'preview'  => true,
                'text-align'=> false,
                'font-size' => true,
                'subsets'   => true,   
                'line-height' => true,
                'color' => false,                
                'word-spacing'  => false,
                'letter-spacing'=> false,
                'default'  => array(
                    //'color'       => '#323232',
                    'font-size'   => '14px',
                    'font-family' => 'Open Sans',
                    'font-weight' => '400',
                    'line-height' => '22px',
                    'subsets'     => 'Latin'
                ),
            ),
            array(
                'id'       => 'opt-typography-head',
                'type'     => 'typography',
                'title'    => esc_html__( 'Headline Font', 'business-one' ),
                'subtitle' => esc_html__( 'Specify the headline font properties.', 'business-one' ),
                'output'   => array('.pricing-block.active .info,h1,h2,h3,h4,h5,h6,.h1,.h2,.h3,.h4,.h5,.h6,.price,.counter p,.single-product .single_add_to_cart_button,.businessone-btn2'),
                'google'   => true,    
                'font-weight' => false,
                'font-backup' => true,            
                'preview'  => true,
                'text-align'=> false,
                'font-size' => false,
                'subsets'   => true,   
                'line-height' => false,
                'color' => false,                
                'word-spacing'  => false,
                'letter-spacing'=> false,
                'default'  => array(
                    //'color'       => '#323232',
                    //'font-size'   => '16px',
                    'font-family' => 'Poppins',
                    //'font-weight' => '400',
                   // 'line-height' => '22px',
                    'subsets'     => 'Latin'
                ),
            ),
           
          
        )
    ) );


    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Social Media', 'business-one' ),
        'id'               => 'social',               
        'icon'             => 'el el-comment-alt'
    ) );  


    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Facebok', 'business-one' ),
        'id'     => 'social-facebook',      
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'facebook',
                'type'     => 'text',
                'title'    => esc_html__( 'Facebok', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) ); 

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Twitter', 'business-one' ),
        'id'     => 'social-twitter',      
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'twitter',
                'type'     => 'text',
                'title'    => esc_html__( 'Twitter', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Youtube', 'business-one' ),
        'id'     => 'social-youtube',    
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'youtube',
                'type'     => 'text',
                'title'    => esc_html__( 'Youtube', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Pinterest', 'business-one' ),
        'id'     => 'social-pinterest',    
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'pinterest',
                'type'     => 'text',
                'title'    => esc_html__( 'Pinterest', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'LinkedIn', 'business-one' ),
        'id'     => 'social-linkedin',    
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'linkedin',
                'type'     => 'text',
                'title'    => esc_html__( 'LinkedIn', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Google +', 'business-one' ),
        'id'     => 'social-googleplus',    
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'googleplus',
                'type'     => 'text',
                'title'    => esc_html__( 'Google +', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'RSS', 'business-one' ),
        'id'     => 'social-rss',    
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'rss',
                'type'     => 'text',
                'title'    => esc_html__( 'RSS', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Tumblr', 'business-one' ),
        'id'     => 'social-tumblr',    
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'tumblr',
                'type'     => 'text',
                'title'    => esc_html__( 'Tumblr', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Instagram', 'business-one' ),
        'id'     => 'social-instagram',    
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'instagram',
                'type'     => 'text',
                'title'    => esc_html__( 'Instagram', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Foursquare', 'business-one' ),
        'id'     => 'social-foursquare',    
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'foursquare',
                'type'     => 'text',
                'title'    => esc_html__( 'Foursquare', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Vimeo', 'business-one' ),
        'id'     => 'social-vimeo',    
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'vimeo',
                'type'     => 'text',
                'title'    => esc_html__( 'Vimeo', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Behance', 'business-one' ),
        'id'     => 'social-behance',    
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'behance',
                'type'     => 'text',
                'title'    => esc_html__( 'Behance', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Dribbble', 'business-one' ),
        'id'     => 'social-dribbble',    
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'dribbble',
                'type'     => 'text',
                'title'    => esc_html__( 'Dribbble', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Flickr', 'business-one' ),
        'id'     => 'social-flickr',    
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'flickr',
                'type'     => 'text',
                'title'    => esc_html__( 'Flickr', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Github', 'business-one' ),
        'id'     => 'social-github',    
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'github',
                'type'     => 'text',
                'title'    => esc_html__( 'Github', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Soundcloud', 'business-one' ),
        'id'     => 'social-soundcloud',    
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'soundcloud',
                'type'     => 'text',
                'title'    => esc_html__( 'Soundcloud', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Spotify', 'business-one' ),
        'id'     => 'social-spotify',    
        'subsection'=>true,
        'fields' => array(
            array(
                'id'       => 'spotify',
                'type'     => 'text',
                'title'    => esc_html__( 'Spotify', 'business-one' ),                
                'desc'     => esc_html__( 'URL Validated', 'business-one' ),               
                'validate' => 'url'                
            ),           
        )
    ) );



    /*
     * <--- END SECTIONS
     */
